@@ -1,6 +1,6 @@
 pub mod gamma;
 pub mod ignore_case_str;
 pub mod ignore_case_string;
-pub mod string_tokenizer;
+pub mod splitter;
 pub mod extensions;
 pub mod approx;
